Package 'epiparameterDB'

Title: Database of Epidemiological Parameters
Description: A data package containing a database of epidemiological parameters. It stores the data for the 'epiparameter' R package. Epidemiological parameter estimates are extracted from the literature.
Authors: Joshua W. Lambert [cre, aut, cph] (ORCID: <https://orcid.org/0000-0001-5218-3046>), Adam Kucharski [aut] (ORCID: <https://orcid.org/0000-0001-8814-9421>), Carmen Tamayo Cuartero [aut] (ORCID: <https://orcid.org/0000-0003-4184-2864>), London School of Hygiene and Tropical Medicine, LSHTM [cph] (ROR: <https://ror.org/00a0jsq62>)
Maintainer: Joshua W. Lambert <[email protected]>
License: CC0
Version: 0.1.0.9000
Built: 2026-05-29 08:53:35 UTC
Source: https://github.com/epiverse-trace/epiparameterDB

Help Index


A list of epidemiological parameters.

Description

A list of epidemiological parameters.

Usage

epiparameterDB

Format

epiparameterDB

A list of epidemiological parameters read from extdata/parameters.json with 133 database entries. The object is tagged with the class attribute ⁠<epiparameterDB>⁠ to validate the parameter library has been loaded using the {epiparameterDB} package.